For detailed documentation about this software,
see <http://www.live555.com/liveMedia/>

This repository creates an RTSP Proxy Server python module for use in [Onvif-GUI](https://github.com/sr99622@gmail.com) 

### License: LGPLv3

    Copyright (c) 2024 Stephen Rhodes 

    This library is free software; you can redistribute it and/or modify it under
    the terms of the GNU Lesser General Public License as published by the
    Free Software Foundation; either version 3 of the License, or (at your
    option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
    more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this library; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

This software is based upon previous works in live555

### License: LGPLv3

    Copyright (c) 1996-2024 Live Networks, Inc.  All rights reserved.

    This library is free software; you can redistribute it and/or modify it under
    the terms of the GNU Lesser General Public License as published by the
    Free Software Foundation; either version 3 of the License, or (at your
    option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
    more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this library; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

